pub struct IndexeddbEventCacheStore { /* private fields */ }Expand description
A type for providing an IndexedDB implementation of EventCacheStore.
This is meant to be used as a backend to EventCacheStore in browser
contexts.
Implementations
Sourceimpl IndexeddbEventCacheStore
impl IndexeddbEventCacheStore
Sourcepub fn builder() -> IndexeddbEventCacheStoreBuilder
pub fn builder() -> IndexeddbEventCacheStoreBuilder
Provides a type with which to conveniently build an
IndexeddbEventCacheStore
Sourcepub fn transaction<'a>(
&'a self,
stores: &[&str],
mode: IdbTransactionMode,
) -> Result<IndexeddbEventCacheStoreTransaction<'a>, IndexeddbEventCacheStoreError>
pub fn transaction<'a>( &'a self, stores: &[&str], mode: IdbTransactionMode, ) -> Result<IndexeddbEventCacheStoreTransaction<'a>, IndexeddbEventCacheStoreError>
Initializes a new transaction on the underlying IndexedDB database and returns a handle which can be used to combine database operations into an atomic unit.